package de.hft.stuttgart.citydoctor2.webservice;

import java.sql.Driver;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.util.Enumeration;

import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;
import javax.servlet.annotation.WebListener;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import de.hft.stuttgart.citydoctor2.webservice.database.ModelQueries;
import de.hft.stuttgart.citydoctor2.webservice.utils.HibernateUtils;

@WebListener
public class ServletInitListener implements ServletContextListener {
	
	private static Logger logger = LogManager.getLogger(ServletInitListener.class);

	@Override
	public void contextInitialized(ServletContextEvent sce) {
		HibernateUtils.init();
		logger.info("Removing models in state 'parsing'");
		ModelQueries.cleanup();
	}

	@Override
	public void contextDestroyed(ServletContextEvent sce) {
		HibernateUtils.shutdown();
		ClassLoader cl = Thread.currentThread().getContextClassLoader();
        Enumeration<Driver> drivers = DriverManager.getDrivers();
        while (drivers.hasMoreElements()) {
            Driver driver = drivers.nextElement();
            if (driver.getClass().getClassLoader() == cl) {
                try {
                    DriverManager.deregisterDriver(driver);
                    logger.info("Deregistering JDBC driver: {}", driver);
                } catch (SQLException e) {
                	logger.error("Error deregistering driver {}", driver);
                	logger.error("", e);
                }
            }
        }
	}

}
